Stats

Struct Stats 

pub struct Stats {
    pub nodes: u32,
    pub scopes: u32,
    pub symbols: u32,
    pub references: u32,
}
Statistics about data held in Semantic.

Comprises number of AST nodes, scopes, symbols, and references.

These counts can be used to pre-allocate sufficient capacity in AstNodes, ScopeTree, and SymbolTable to store info for all these items.

Example

use oxc_ast::ast::Program;
use oxc_semantic::{Semantic, Stats};

fn print_stats_from_semantic(semantic: &Semantic) {
    dbg!(semantic.stats());
}

fn print_stats_from_ast(program: &Program) {
    dbg!(Stats::count(program));
}

Fields

nodes: u32

Number of AST nodes.

scopes: u32

Number of lexical scopes.

symbols: u32

Number of semantic symbols.

references: u32

Number of identifier references.

Implementations

Source

impl Stats

pub fn new(nodes: u32, scopes: u32, symbols: u32, references: u32) -> Self

Create new Stats from specified counts.

pub fn count(program: &Program<'_>) -> Self

Gather Stats by visiting AST and counting nodes, scopes, symbols, and references.

Nodes, scopes and references counts will be exactly accurate. Symbols count may be an over-estimate if there are multiple declarations for a single symbol. e.g. var x; var x; will produce a count of 2 symbols, but this is actually only 1 symbol.

If semantic analysis has already been run on AST, prefer getting counts with Semantic::stats. They will be 100% accurate, and very cheap to obtain, whereas this method performs a complete AST traversal.

pub fn increase_by(self, excess: f64) -> Self

Increase scope, symbol, and reference counts by provided excess.

excess is provided as a fraction. e.g. to over-allocate by 20%, pass 0.2 as excess.

pub fn assert_accurate(self, actual: Self)

Assert that estimated Stats match actual.

Panics

Panics if stats are not accurate.