pub struct SymbolId(/* private fields */);Implementations
Sourceimpl SymbolId
impl SymbolId
Sourcepub const CHECKS_MAX_INDEX: bool = true
pub const CHECKS_MAX_INDEX: bool = true
Whether this index type performs bounds checking.
Sourcepub const fn from_raw(value: NonMaxU32) -> SymbolId
pub const fn from_raw(value: NonMaxU32) -> SymbolId
Create an index from a raw NonMaxU32 value.
Sourcepub fn from_foreign<F>(value: F) -> SymbolIdwhere
F: Idx,
pub fn from_foreign<F>(value: F) -> SymbolIdwhere
F: Idx,
Convert an index from another index type.
Sourcepub const unsafe fn from_usize_unchecked(value: usize) -> SymbolId
pub const unsafe fn from_usize_unchecked(value: usize) -> SymbolId
Create an index from a usize without bounds checking.
SAFETY
The caller must ensure value < (u32::MAX as usize).
Sourcepub const unsafe fn from_raw_unchecked(raw: u32) -> SymbolId
pub const unsafe fn from_raw_unchecked(raw: u32) -> SymbolId
Create an index from a raw u32 without bounds checking.
SAFETY
The caller must ensure the value is not u32::MAX.
Sourcepub const fn from_usize(value: usize) -> SymbolId
pub const fn from_usize(value: usize) -> SymbolId